@@ -23,7 +23,7 @@ sub connect {
 
     my $schema = $self->clone->connection($dsn,@_);
 
-    my $tp = TreePath->new(  conf => $config, debug => 0 );
+    my $tp = TreePath->new(  conf => $config );
 
     $tp->schema($schema);
 
