@@ -10,7 +10,7 @@ Schema::TPathSync::Result::Comment
 use Moose;
 use MooseX::NonMoose;
 use MooseX::MarkAsMethods autoclean => 1;
-extends 'DBIx::Class::Core';
+extends 'DBIx::Class::ResultSet::TP';
 
 
 __PACKAGE__->load_components();
@@ -38,33 +38,6 @@ __PACKAGE__->belongs_to(
 );
 
 
-sub insert {
-    my $self = shift;
-
-    #print "Add a new comment\n";
-    my $return = $self->next::method( @_ );
-
-    my $tp = $self->result_source->schema->treepath;
-    my $obj = $tp->_row_to_obj($self);
-    $tp->add($obj);
-    return $return;
-}
-
-sub update {
-    my $self = shift;
-
-    print "Update a comment\n";
-
-    return $self->next::method( @_ );
-}
-
-sub delete {
-    my $self = shift;
-
-    print "Del a comment\n";
-
-    return $self->next::method( @_ );
-  }
 
 =head1 NAME
 
