@@ -64,7 +64,7 @@ __PACKAGE__->set_primary_key("id");
 
 =cut
 
-__PACKAGE__->add_unique_constraint("file_unique", ["file"]);
+__PACKAGE__->add_unique_constraint("file_page_id_unique", ["file", "page_id"]);
 
 
 =head1 UNIQUE CONSTRAINTS
